@@ -24,6 +24,7 @@ class BatchDataCollection(BaseCollection):
         super().__init__(session=session)
         self.base_path = f"/api/{BatchDataCollection._api_version}/batchdata"
 
+    @validate_call
     def create_batch_data(self, *, task_id: TaskId):
         """
         Create a new batch data entry.
@@ -82,8 +83,9 @@ class BatchDataCollection(BaseCollection):
         response = self.session.get(self.base_path, params=params)
         return BatchData(**response.json())
 
+    @validate_call
     def update_used_batch_amounts(
-        self, *, task_id: str, patches: list[BatchValuePatchPayload]
+        self, *, task_id: TaskId, patches: list[BatchValuePatchPayload]
     ) -> None:
         """
         Update the used batch amounts for a given task ID.
