@@ -243,7 +243,7 @@ class TaskCollection(BaseCollection):
         tags: list[str] | None = None,
         task_id: list[TaskId] | None = None,
         linked_task: list[TaskId] | None = None,
-        category: TaskCategory | None = None,
+        category: TaskCategory | str | list[str] | None = None,
         albert_id: list[str] | None = None,
         data_template: list[str] | None = None,
         assigned_to: list[str] | None = None,
@@ -347,7 +347,7 @@ class TaskCollection(BaseCollection):
         tags: list[str] | None = None,
         task_id: list[TaskId] | None = None,
         linked_task: list[TaskId] | None = None,
-        category: TaskCategory | None = None,
+        category: TaskCategory | str | list[str] | None = None,
         albert_id: list[str] | None = None,
         data_template: list[str] | None = None,
         assigned_to: list[str] | None = None,
