@@ -26,6 +26,7 @@ _ALBERT_PREFIXES = {
     "PropertyDataId": "PTD",
     "ReportId": "REP",
     "RowId": "ROW",
+    "RuleId": "RUL",
     "SynthesisId": "SYN",
     "TagId": "TAG",
     "TaskId": "TAS",
@@ -204,6 +205,20 @@ def ensure_custom_template_id(id: str) -> str:
 CustomTemplateId = Annotated[str, AfterValidator(ensure_custom_template_id)]
 
 
+def ensure_entity_type_id(id: str) -> str:
+    return _ensure_albert_id(id, "EntityType")
+
+
+EntityTypeId = Annotated[str, AfterValidator(ensure_entity_type_id)]
+
+
+def ensure_rule_id(id: str) -> str:
+    return _ensure_albert_id(id, "RuleId")
+
+
+RuleId = Annotated[str, AfterValidator(ensure_rule_id)]
+
+
 def ensure_entity_type_id(id: str) -> str:
     return _ensure_albert_id(id, "EntityTypeId")
 
