@@ -1,6 +1,6 @@
 from pydantic import Field
 
-from albert.resources.base import BaseResource
+from albert.core.shared.models.base import BaseResource
 
 
 class UnNumber(BaseResource):
